@@ -1,6 +1,3 @@
-context("Testing lm tidiers")
-
-
 # FUNCTION: sw_*.default -----
 test_that("sw_*.default test returns tibble with correct rows and columns.", {
 
@@ -9,14 +6,14 @@ test_that("sw_*.default test returns tibble with correct rows and columns.", {
 
     # sw_tidy ----
     test <- sw_tidy(fit_lm)
-    expect_is(test, "tbl")
+    expect_s3_class(test, "tbl")
     # expect_false(any(lapply(test, is.factor) %>% unlist())) # No factors
     expect_equal(nrow(test), 2)
     expect_equal(ncol(test), 5)
 
     # sw_glance ----
     test <- sw_glance(fit_lm)
-    expect_is(test, "tbl")
+    expect_s3_class(test, "tbl")
     # expect_false(any(lapply(test, is.factor) %>% unlist())) # No factors
     expect_equal(nrow(test), 1)
     # expect_equal(ncol(test), 12)
@@ -26,7 +23,7 @@ test_that("sw_*.default test returns tibble with correct rows and columns.", {
         suppressWarnings(
             sw_augment(fit_lm)
         )
-    expect_is(test, "tbl")
+    expect_s3_class(test, "tbl")
     # expect_false(any(lapply(test, is.factor) %>% unlist())) # No factors
     expect_equal(nrow(test), 32)
     # expect_equal(ncol(test), 8)
