@@ -1,6 +1,3 @@
-context("Testing STL tidiers")
-
-
 # FUNCTION sw_*.stl -----
 test_that("sw_*.stl test returns tibble with correct rows and columns.", {
 
@@ -10,17 +7,17 @@ test_that("sw_*.stl test returns tibble with correct rows and columns.", {
 
     # sw_tidy_decomp ----
     test <- sw_tidy_decomp(fit_stl)
-    expect_is(test, "tbl")
+    expect_s3_class(test, "tbl")
     expect_equal(nrow(test), 72)
     expect_equal(ncol(test), 6)
 
     # stlm() ----
     fit_stlm <- USAccDeaths %>%
-        stlm(modelfunction=ar)
+        forecast::stlm(modelfunction=ar)
 
     # sw_tidy_decomp ----
     test <- sw_tidy_decomp(fit_stlm)
-    expect_is(test, "tbl")
+    expect_s3_class(test, "tbl")
     expect_equal(nrow(test), 72)
     expect_equal(ncol(test), 6)
 
@@ -29,16 +26,16 @@ test_that("sw_*.stl test returns tibble with correct rows and columns.", {
 
     # data_ts <- USAccDeaths %>%
     #     tk_tbl() %>%
-    #     mutate(index = as_date(index)) %>%
+    #     dplyr::mutate(index = lubridateLLas_date(index)) %>%
     #     tk_ts(start = 1973, freq = 12, silent = TRUE)
     #
     # fit <- stl(data_ts, s.window = "periodic")
     #
     # # timetk_idx sw_tidy_decomp -----
     # test <- fit %>% sw_tidy_decomp()
-    # expect_equal(class(test$index), "yearmon")
+    # expect_s3_class(test$index, "yearmon")
 
     # timekix_idx not supported with stats::stl()
-    # test <- fit %>% sw_tidy_decomp(timetk_idx = T)
-    # expect_equal(class(test$index), "Date")
+    # test <- fit %>% sw_tidy_decomp(timetk_idx = TRUE)
+    # expect_s3_class(test$index, "Date")
 })
